@@ -1,15 +1,17 @@
 
 # fit the parameters of the bayesian network for a given network stucture.
-bn.fit.backend = function(x, data, cluster = NULL, method = "mle", extra.args,
+bn.fit.backend = function(x, data, cluster = NULL, method, extra.args,
     data.info, keep.fitted = TRUE, debug = FALSE) {
 
   # define the fitting functions.
-  if (data.info$type %in% discrete.data.types)
+  if (method %in% c("mle", "bayes"))
     fit = bn.fit.backend.discrete
-  else if (data.info$type == "continuous")
+  else if (method == "mle-g")
     fit = bn.fit.backend.continuous
-  else if (data.info$type == "mixed-cg")
+  else if (method == "mle-cg")
     fit = bn.fit.backend.mixedcg
+  else if (method == "hdir")
+    fit = bn.fit.backend.hierarchical
 
   # fit the parameters of each node.
   fitted = smartSapply(cluster, names(x$nodes), fit, dag = x, data = data,
@@ -20,7 +22,7 @@ bn.fit.backend = function(x, data, cluster = NULL, method = "mle", extra.args,
   class = c(orig.class[orig.class != "bn"], "bn.fit",
             fitted.from.data[[data.info$type]])
   # preserve the training node label from Bayesian network classifiers.
-  if (x$learning$algo %in% classifiers)
+  if (x$learning$algo %in% classification.algorithms)
     fitted = structure(fitted, class = class, training = x$learning$args$training)
   else
     fitted = structure(fitted, class = class)
@@ -48,55 +50,98 @@ bn.fit.backend.discrete = function(dag, node, data, method, extra.args,
 
   }#THEN
 
-  if (method == "mle") {
-
-    # the parameters of the multinomial distribution are the probabilities
-    # of the levels of the node and the configurations of its parents.
-    tab = .table(data[, c(node, parents), drop = FALSE],
-            with.missing = !all(data.info$complete.nodes[c(node, parents)]))
-    # switch from joint to conditional probabilities.
-    tab = prop.table(tab, margin = seq(length(parents) + 1)[-1])
-
-    # replace unidentifiable conditional probabilities corresponding to
-    # unobserved parent configurations with uniform probabilites to prevent
-    # NAs from propagating.
-    if (extra.args$replace.unidentifiable)
-      tab[is.na(tab)] = 1/(nrow(tab))
-
-  }#THEN
-  else {
-
-    # the parameters of the multinomial distribution are the expected values
-    # of the corresponding parameters of the posterior Dirichlet distribution.
-    tab = .table(data[, c(node, parents), drop = FALSE],
-            with.missing = !all(data.info$complete.nodes[c(node, parents)]))
-    tab = tab + extra.args$iss / prod(dim(tab))
-    # switch from joint to conditional probabilities.
-    tab = prop.table(tab, margin = seq(length(parents) + 1)[-1])
-
-  }#ELSE
+  # the "method" argument is not used explicity, but if "mle" the imaginary
+  # sample size is not defined and thus is read as NULL.
+  cptable =
+    .Call("call_classic_discrete_parameters",
+          data = data,
+          node = node,
+          parents = parents,
+          iss = extra.args$iss,
+          replace.unidentifiable = isTRUE(extra.args$replace.unidentifiable),
+          missing = !all(data.info$complete.nodes[c(node, parents)]))
 
   # this is to preserve the ordering of the factor.
   class = ifelse(ordered.factor, "bn.fit.onode", "bn.fit.dnode")
 
   # marginal tables have no dimension names in bnlearn.
-  tab = cptattr(tab)
+  cptable = cptattr(cptable)
 
   if (debug)
-    cat("  > fitted ", length(tab),
+    cat("  > fitted ", length(cptable),
       ifelse(length(parents) > 0, " conditional", " marginal"),
       " probabilities.\n", sep = "")
 
   structure(list(node = node, parents = parents, children = children,
-    prob = tab), class = class)
+    prob = cptable), class = class)
 
 }#BN.FIT.BACKEND.DISCRETE
 
+bn.fit.backend.hierarchical = function(dag, node, data, method, extra.args,
+    data.info, keep.fitted = TRUE, debug = FALSE) {
+
+  group = extra.args$group
+  parents = setdiff(dag$nodes[[node]]$parents, group)
+  children = dag$nodes[[node]]$children
+  # is the data an ordered or unordered factor?
+  ordered.factor = is(data[, node], "ordered")
+
+  if (debug) {
+
+    cat("* fitting parameters of node", node,
+      ifelse(ordered.factor, "(ordinal).\n", "(discrete).\n"))
+
+  }#THEN
+
+  # the grouping variable is different from the rest since it has no pooling.
+  if (node == group) {
+
+    # fit the parameters of the grouping node using maximum likelihood.
+    return(bn.fit.backend.discrete(dag = dag, node = node, data = data,
+             data.info = data.info, method = "mle",
+             extra.args = list(replace.unidentifiable = FALSE),
+             debug = FALSE))
+
+  }#THEN
+
+  if (debug) {
+
+    cat("  > grouping variable:", group, "\n")
+    if (length(parents) > 0)
+      cat("  > found parents:", parents, "\n")
+
+  }#THEN
+
+  cptable =
+    .Call("call_hierarchical_dirichlet_parameters",
+          data = data,
+          node = node,
+          parents = parents,
+          group = group,
+          alpha0 = extra.args$alpha0,
+          iss = extra.args$iss,
+          missing = !all(data.info$complete.nodes[c(node, parents, group)]),
+          debug = debug)
+
+  # this is to preserve the ordering of the factor.
+  class = ifelse(ordered.factor, "bn.fit.onode", "bn.fit.dnode")
+
+  # marginal tables have no dimension names in bnlearn.
+  cptable = cptattr(cptable)
+
+  if (debug)
+    cat("  > fitted ", length(cptable),
+      ifelse(length(parents) > 0, " conditional", " marginal"),
+      " probabilities.\n", sep = "")
+
+  structure(list(node = node, parents = c(parents, group), children = children,
+                 prob = cptable), class = class)
+
+}#BN.FIT.BACKEND.HIERARCHICAL
+
 bn.fit.backend.continuous = function(dag, node, data, method, extra.args,
     data.info, keep.fitted = TRUE, debug = FALSE) {
 
-  # cache the sample size.
-  n = nrow(data)
   # store the labels of the parents and the children to get them only once.
   parents = dag$nodes[[node]]$parents
   children = dag$nodes[[node]]$children
@@ -111,25 +156,16 @@ bn.fit.backend.continuous = function(dag, node, data, method, extra.args,
 
   }#THEN
 
-  if (method == "mle") {
-
-    # the relevant quantities of the normal distribution are those usually found
-    # in an lm object: coefficients, fitted values and residuals, plus the
-    # residuals standard deviation.
-    lmreg = fast.lm(data, node, parents, keep.fitted = keep.fitted,
-              with.missing = !all(data.info$complete.nodes[c(node, parents)]))
-
-    # replace unidentifiable regression coefficients and the standard error
-    # with zeroes to prevent NAs from propagating.
-    if (extra.args$replace.unidentifiable) {
-
-      lmreg$coefficients[is.na(lmreg$coefficients)] = 0
-      if (is.na(lmreg$sd))
-        lmreg$sd = 0
-
-    }#THEN
-
-  }#THEN
+  # the key elements found in an lm object: coefficients, fitted values and
+  # residuals, plus the standard error.
+  lmreg =
+    .Call("call_gaussian_ols_parameters",
+          data = data,
+          node = node,
+          parents = parents,
+          keep.fitted = keep.fitted,
+          replace.unidentifiable = isTRUE(extra.args$replace.unidentifiable),
+          missing = !all(data.info$complete.nodes[c(node, parents)]))
 
   structure(c(list(node = node, parents = parents, children = children),
     lmreg), class = "bn.fit.gnode")
@@ -145,7 +181,7 @@ bn.fit.backend.mixedcg = function(dag, node, data, method, extra.args,
   # discrete nodes are parameterized by CPTs.
   if (is(node.data, "factor"))
     return(bn.fit.backend.discrete(dag = dag, node = node, data = data,
-      method = method, extra.args = extra.args, data.info = data.info,
+      method = "mle", extra.args = extra.args, data.info = data.info,
       debug = debug))
 
   # store the labels of the parents and the children to get them only once.
@@ -157,7 +193,7 @@ bn.fit.backend.mixedcg = function(dag, node, data, method, extra.args,
     # this node has no parents, so the local distribution is just a linear
     # regression against the sample mean.
     return(bn.fit.backend.continuous(dag = dag, node = node, data = data,
-      method = method, extra.args = extra.args, keep.fitted = keep.fitted,
+      method = "mle-g", extra.args = extra.args, keep.fitted = keep.fitted,
       data.info = data.info, debug = debug))
 
   }#THEN
@@ -171,7 +207,7 @@ bn.fit.backend.mixedcg = function(dag, node, data, method, extra.args,
     if (type.from.parents == "continuous") {
 
       return(bn.fit.backend.continuous(dag = dag, node = node, data = data,
-        method = method, extra.args = extra.args, keep.fitted = keep.fitted,
+        method = "mle-g", extra.args = extra.args, keep.fitted = keep.fitted,
         data.info = data.info, debug = debug))
 
     }#THEN
@@ -193,37 +229,21 @@ bn.fit.backend.mixedcg = function(dag, node, data, method, extra.args,
 
       # perform a linear regression for each configuration of the discrete
       # parents.
-      lmreg = fast.cglm(data, node, parents = continuous.parents,
-                configs = configs, keep.fitted = keep.fitted,
-                with.missing = !all(data.info$complete.nodes[c(node, parents)]))
+      lmreg =
+        .Call("call_mixture_gaussian_ols_parameters",
+              data = data,
+              node = node,
+              parents = continuous.parents,
+              configs = configs,
+              keep.fitted = keep.fitted,
+              replace.unidentifiable = isTRUE(extra.args$replace.unidentifiable),
+              missing = !all(data.info$complete.nodes[c(node, parents)]))
 
-      # replace unidentifiable regression coefficients and standard errors with
-      # zeroes to prevent NAs from propagating.
-      if (extra.args$replace.unidentifiable) {
-
-        lmreg$coefficients[is.na(lmreg$coefficients)] = 0
-        lmreg$sd[is.na(lmreg$sd)] = 0
-
-      }#THEN
-
-      if (keep.fitted) {
-
-        structure(c(list(node = node, parents = parents, children = children,
-          dparents = which(parents %in% discrete.parents),
-          gparents = which(parents %in% continuous.parents),
-          dlevels = lapply(parents.data[parents %in% discrete.parents], levels)),
-          lmreg), class = "bn.fit.cgnode")
-
-      }#THEN
-      else {
-
-        structure(c(list(node = node, parents = parents, children = children,
-          dparents = which(parents %in% discrete.parents),
-          gparents = which(parents %in% continuous.parents),
-          dlevels = lapply(parents.data[parents %in% discrete.parents], levels)),
-          lmreg), class = "bn.fit.cgnode")
-
-      }#ELSE
+      structure(c(list(node = node, parents = parents, children = children,
+        dparents = which(parents %in% discrete.parents),
+        gparents = which(parents %in% continuous.parents),
+        dlevels = lapply(parents.data[parents %in% discrete.parents], levels)),
+        lmreg), class = "bn.fit.cgnode")
 
     }#ELSE
 
