@@ -18,7 +18,7 @@ void topological_sort(SEXP fitted, int *poset, int nnodes);
 /* from path.c */
 int c_has_path(int start, int stop, int *amat, int n, SEXP nodes,
     bool ugraph, bool notdirect, int *path, int *counter, bool debugging);
-int c_directed_path(int start, int stop, int *amat, int n, SEXP nodes,
+bool c_directed_path(int start, int stop, int *amat, int n, SEXP nodes,
     int *path, int *counter, bool debugging);
 int c_uptri3_path(short int *uptri, int *depth, int from, int to, int nnodes,
     SEXP nodes, bool debugging);
