@@ -43,7 +43,7 @@ extern SEXP fit2arcs(SEXP);
 extern SEXP fitted_mb(SEXP, SEXP);
 extern SEXP fitted_vs_data(SEXP, SEXP, SEXP);
 extern SEXP gaussian_ols_parameters(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP get_test_counter();
+extern SEXP get_test_counter(void);
 extern SEXP gpred(SEXP, SEXP, SEXP);
 extern SEXP has_pdag_path(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP hc_opt_step(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
@@ -72,14 +72,14 @@ extern SEXP normalize_cpt(SEXP);
 extern SEXP nparams_cgnet(SEXP, SEXP, SEXP);
 extern SEXP nparams_fitted(SEXP, SEXP, SEXP);
 extern SEXP num_arcs(SEXP);
-extern SEXP onLoad();
-extern SEXP onUnload();
+extern SEXP onLoad(void);
+extern SEXP onUnload(void);
 extern SEXP ordered_graph(SEXP, SEXP, SEXP);
 extern SEXP pdag_extension(SEXP, SEXP, SEXP);
 extern SEXP pdag2dag(SEXP, SEXP);
 extern SEXP per_node_score(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP rbn_master(SEXP, SEXP, SEXP, SEXP);
-extern SEXP reset_test_counter();
+extern SEXP reset_test_counter(void);
 extern SEXP root_nodes(SEXP, SEXP);
 extern SEXP roundrobin_test(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP score_cache_fill(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
